@@ -1,5 +1,5 @@
 package AI::ConfusionMatrix;
-$AI::ConfusionMatrix::VERSION = '0.003';
+$AI::ConfusionMatrix::VERSION = '0.004';
 use Carp;
 use Exporter 'import';
 our @EXPORT= qw (makeConfusionMatrix);
@@ -23,10 +23,10 @@ sub makeConfusionMatrix {
         ++$n;
         $stats{$expected}{'fn'} = 0;
         $stats{$expected}{'tp'} = 0;
+        # Ensure that the False Positive counter is defined to be able to compute the total later
+        $stats{$expected}{'fp'} //= 0;
 
         for my $predicted (keys %{$matrix->{$expected}}) {
-            # Ensure that the False Positive counter is defined to be able to compute the total later
-            $stats{$predicted}{'fp'} //= 0;
             $stats{$expected}{'total'} += $matrix->{$expected}->{$predicted};
             $stats{$expected}{'tp'} += $matrix->{$expected}->{$predicted} if $expected == $predicted;
             if ($expected != $predicted) {
@@ -46,11 +46,10 @@ sub makeConfusionMatrix {
         $totals{'tp'}    += $stats{$expected}{'tp'};
         $totals{'fn'}    += $stats{$expected}{'fn'};
         $totals{'fp'}    += $stats{$expected}{'fp'};
-        $totals{'acc'}   += $stats{$expected}{'acc'};
         $stats{$expected}{'acc'} .= '%';
     }
 
-    $totals{'acc'} = sprintf("%.2f%%", $totals{'acc'} / @expected);
+    $totals{'acc'} = sprintf("%.2f%%", ($totals{'tp'} * 100) / $totals{'total'});
     @columns = sort @columns;
     map {$array[0] .= ',' . $_} join ',', (@columns, 'TOTAL', 'TP', 'FP', 'FN', 'ACC');
     $n = 1;
@@ -144,30 +143,29 @@ The output will be in CSV. Here is an example:
 
 
     ,1997,1998,2001,2003,2005,2008,2012,2015,TOTAL,TP,FP,FN,ACC
-    1997,1,,,,,,,1,2,1,0,1,50.00%
+    1997,2,,,,,,,,2,2,0,0,100.00%
     1998,,1,,,,,,,1,1,0,0,100.00%
     2001,,,1,,,,,,1,1,0,0,100.00%
-    2003,,,,5,,,,2,7,5,0,2,71.43%
-    2005,,,,,5,,,4,9,5,0,4,55.56%
+    2003,,,,5,,,1,1,7,5,0,2,71.43%
+    2005,,,,,7,,,2,9,7,0,2,77.78%
     2008,,,,,,3,,,3,3,0,0,100.00%
-    2012,,,,,,,5,,5,5,0,0,100.00%
-    2015,,,,,,,,2,2,2,7,0,100.00%
-    TOTAL,1,1,1,5,5,3,5,9,30,23,7,7,84.62%
+    2012,,,,,,,5,,5,5,1,0,100.00%
+    2015,,,,,,,,8,8,8,3,0,100.00%
+    TOTAL,2,1,1,5,7,3,6,11,36,32,4,4,88.89%
 
 Prettified:
 
-
-|       | 1997 | 1998 | 2001 | 2003 | 2005 | 2008 | 2012 | 2015 | TOTAL | TP | FP | FN | ACC     |
-|-------|------|------|------|------|------|------|------|------|-------|----|----|----|---------|
-| 1997  | 1    |      |      |      |      |      |      | 1    | 2     | 1  | 0  | 1  | 50.00%  |
-| 1998  |      | 1    |      |      |      |      |      |      | 1     | 1  | 0  | 0  | 100.00% |
-| 2001  |      |      | 1    |      |      |      |      |      | 1     | 1  | 0  | 0  | 100.00% |
-| 2003  |      |      |      | 5    |      |      |      | 2    | 7     | 5  | 0  | 2  | 71.43%  |
-| 2005  |      |      |      |      | 5    |      |      | 4    | 9     | 5  | 0  | 4  | 55.56%  |
-| 2008  |      |      |      |      |      | 3    |      |      | 3     | 3  | 0  | 0  | 100.00% |
-| 2012  |      |      |      |      |      |      | 5    |      | 5     | 5  | 0  | 0  | 100.00% |
-| 2015  |      |      |      |      |      |      |      | 2    | 2     | 2  | 7  | 0  | 100.00% |
-| TOTAL | 1    | 1    | 1    | 5    | 5    | 3    | 5    | 9    | 30    | 23 | 7  | 7  | 84.62%  |
+    |       | 1997 | 1998 | 2001 | 2003 | 2005 | 2008 | 2012 | 2015 | TOTAL | TP | FP | FN | ACC     |
+    |-------|------|------|------|------|------|------|------|------|-------|----|----|----|---------|
+    | 1997  | 2    |      |      |      |      |      |      |      | 2     | 2  | 0  | 0  | 100.00% |
+    | 1998  |      | 1    |      |      |      |      |      |      | 1     | 1  | 0  | 0  | 100.00% |
+    | 2001  |      |      | 1    |      |      |      |      |      | 1     | 1  | 0  | 0  | 100.00% |
+    | 2003  |      |      |      | 5    |      |      | 1    | 1    | 7     | 5  | 0  | 2  | 71.43%  |
+    | 2005  |      |      |      |      | 7    |      |      | 2    | 9     | 7  | 0  | 2  | 77.78%  |
+    | 2008  |      |      |      |      |      | 3    |      |      | 3     | 3  | 0  | 0  | 100.00% |
+    | 2012  |      |      |      |      |      |      | 5    |      | 5     | 5  | 1  | 0  | 100.00% |
+    | 2015  |      |      |      |      |      |      |      | 8    | 8     | 8  | 3  | 0  | 100.00% |
+    | TOTAL | 2    | 1    | 1    | 5    | 7    | 3    | 6    | 11   | 36    | 32 | 4  | 4  | 88.89%  |
 
 =over
 
